@@ -1,5 +1,7 @@
 from contextlib import contextmanager
 
+from frmf.response import abort
+
 
 class _MetaSingleton(type):
     _instance = {}
@@ -50,4 +52,6 @@ class DBHelper(metaclass=_MetaSingleton):
             yield self.db
             self.db.session.commit()
         except Exception as e:
+            print(e)
             self.db.session.rollback()
+            abort(500)
